Clazz.declarePackage("JM.FF");
(function(){
var c$ = Clazz.decorateAsClass(function(){
this.iVal = null;
this.dVal = null;
this.sVal = null;
Clazz.instantialize(this, arguments);}, JM.FF, "FFParam", null);
})();
;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
